#
# spec file for package dateutils
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dateutils
Version:        0.4.10
Release:        bp156.3.5
Summary:        Command line date and time utilities
License:        BSD-3-Clause
Group:          Productivity/Text/Utilities
URL:            https://github.com/hroptatyr/dateutils/
Source0:        https://github.com/hroptatyr/dateutils/releases/download/v%{version}/%{name}-%{version}.tar.xz
Source1:        https://github.com/hroptatyr/dateutils/releases/download/v%{version}/%{name}-%{version}.tar.asc
Source2:        %{name}.keyring
Patch0:         https://github.com/hroptatyr/dateutils/commit/841c635b.patch
Patch1:         https://github.com/hroptatyr/dateutils/commit/35041f4d.patch
BuildRequires:  octave-devel
BuildRequires:  pkgconfig
BuildRequires:  timezone

%description
Dateutils are a bunch of tools that revolve around fiddling with dates
and times in the command line with a strong focus on use cases that
arise when dealing with large amounts of financial data. Their target
market is shell scripts that need date calculations or calendar
conversions, and as such they are highly pipe-able and modeled after
their well-known cousins (e.g. dtest vs. test, or dgrep vs. grep).

%package octave
Summary:        Dateutils functions for matlab and octave
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       octave

%description octave
Dateutils can be used from within matlab or ocatave.

%prep
%autosetup -p1

%build
%configure \
  --enable-contrib
%make_build

%install
%make_install
rm -rf %{buildroot}%{_datadir}/doc/dateutils
rm -rf %{buildroot}%{_libdir}/octave/site/oct/*/dateutils/tzconv.la

%check
%make_build check

%files
%license LICENSE
%doc README.md
%{_bindir}/*
%{_datadir}/dateutils/
%{_mandir}/man1/*
%{_infodir}/%{name}.info%{?ext_info}

%files octave
%dir %{_libdir}/octave/site/oct/*/dateutils/
%{_libdir}/octave/site/oct/*/dateutils/tzconv.m
%{_libdir}/octave/site/oct/*/dateutils/tzconv.mex

%changelog
* Mon Dec 19 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add upstream patches 35041f4d.patch and 841c635b.patch: Do not
  use Singapore for testing previous transitions, but rather
  Jakarta. Fixes build with timezone 2022g.
* Fri May 27 2022 Michael Vetter <mvetter@suse.com>
- Update to 4.10:
  * do not resort to daisy sequences when incomplete dates are present (#131)
  * upon end-of-buffer finalise the last line (#141)
  * let --empty-mode|-E and --sed-mode|-S play nicely together (#139)
  * adapt CLI behaviour of strptime(1) to the other tools (#142)
* Fri Aug 20 2021 Michael Vetter <mvetter@suse.com>
- Update to 4.9:
  * allow to specify epochs in nanoseconds, %%s%%N (#123)
  * fix nanosecond arithmetic (#124)
  * make cross-compilations easier (#128)
  * mention default timezone (#129)
- Drop upstreamed patches:
  * 0144b15dda4b1ea4fdbeca9f3ecb128eb98772fd.patch
  * a0ebd0037df973aed14779b51d59da3edc506b6a.patch
* Mon May 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add 0144b15dda4b1ea4fdbeca9f3ecb128eb98772fd.patch and
  a0ebd0037df973aed14779b51d59da3edc506b6a.patch: fix test suite
  run on 32bit archs.
* Sun Feb 21 2021 Andreas Stieger <andreas.stieger@gmx.de>
- add upstream signing key
- simplify spec file
* Wed Feb 17 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.4.8:
  * be symmetric about differences, A - B := -(B - A) for A < B
  * fix security issue when reading TZMAP_DIR from environment
  * fix printing of negative 0 (-0)
  * fix issue with tzdata transitions in files with leap second
  * adjustments that are now cut off at expiration time (#121)
- Drop dateutils-remove-deprecated-header.patch: not needed anymore
* Sat Dec 19 2020 malcolmlewis@opensuse.org
- Add dateutils-remove-deprecated-header.patch: Remove deprecated
  glibc sysctl.h header.
* Wed Feb  5 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.4.7:
  * strptime mimics return code behaviour of dateconv
  * use unsigned arithmetic for leap second conversion
  * fix up ymds before adding days or business days
  * drain prchunk if filled with many small lines
* Tue Mar 19 2019 mvetter@suse.com
- Update to 0.4.6:
  * underspecified ISO weekday dates can be parsed
  * adding days to underspecified dates results in proper dates
  * all tools with -S|--sed-mode now support -E|--empty-mode to
    output an empty line when a line cannot be read.
  * dateround supports day, week, month and year classes now
    (issues/92)
  * datediff can determine difference in nanoseconds between
    two time values (issues/94)
* Fri Sep 21 2018 Martin Pluskal <mpluskal@suse.com>
- Simplify conditions
- Run spec-cleaner
* Thu Sep 20 2018 bwiedemann@suse.com
- Update to 0.4.5:
  * dgrep accepts %%c as qualifier in expressions (issue 81)
  * tests work regardless of wall clock time (issue 84)
* Sat Aug 25 2018 jengelh@inai.de
- Ensure neutrality of descriptions.
- Trim idempotent %%if..%%endif guards.
* Tue Aug 14 2018 mvetter@suse.com
- Update to 0.4.4:
  Incompatible changes:
  * suffix `m` is no longer accepted as a synonym for `mo`
    with date-only input, issue #76
  Bugfixes:
  * expose BSD routines (fgetln()) to yuck
  * for dates passed to dateround(1) that coincidentally
    match the roundspecs do read them as dates
  * wrong timestamps read via -i %%s signal error
  * facilitate bmake build
  * time rounding on date-only input keeps the date unchanged
  * dateseq's short-cut iterator (2 date arguments) does not
    interfere with the 3-argument version
  * adding 0 date or time units does not change the summand
  * datezone on times (without date) will return times
  * zones are singletons now, opened and closed only once
* Sat Mar  3 2018 sweet_f_a@gmx.de
- bump version 0.4.3
  * Features:
  - base expansion works for times now
  * Bugfixes:
  - durations in months weeks and days are calculated
    like durations in months and days, consistency
  - am and pm indicators in inputs are handled properly
  - military midnights decay when not printed in full
* Thu Nov  9 2017 sweet_f_a@gmx.de
- revert non-portable changes of the last commit (SLE 11 build)
* Wed Oct 18 2017 aavindraa@gmail.com
- bump version 0.4.2
  * Features:
  - allow %%- specifiers to turn off padding (as GNU date does)
  - support matlab day numbers, as mdn or matlab
  * Bugfixes:
  - fix build issue on FBSD 11
  - allow zones to transition at INT_MAX (mapped to never)
- lint spec file
- move from bitbucket to github link
- remove patch which is upstream now:
  0001-fix-when-printing-zones-transitioning-at-INT_MAX-in-.patch
* Mon Apr  3 2017 sweet_f_a@gmx.de
- fix incompatibility with tzdata/tzcode >= 2017a,
  0001-fix-when-printing-zones-transitioning-at-INT_MAX-in-.patch
* Thu Dec 15 2016 sweet_f_a@gmx.de
- bump version 0.4.1, this is a bugfix release.
  * Bugfixes:
  - bug/50, keep end-of-term (ultimo) property in dateseq(1)
  - allow today/now for ywd dates in 1 parameter dateseq(1)
  - allow different calendars for start and end date in dateseq(1)
  - round time in dateround(1) in zone then convert --from-zone
  - allow SPC padded numerals in %%d input format
  * See info page examples and/or README.
- remove patch which is upstream now:
  0001-Revert-chore-be-more-portable-in-sxe-matlab.m4.patch
* Wed Jun 15 2016 sweet_f_a@gmx.de
- fix .mex file extension for octave plugin,
  0001-Revert-chore-be-more-portable-in-sxe-matlab.m4.patch
- explicit octave plugin file list
- remove *.la files
* Thu Jun  2 2016 sweet_f_a@gmx.de
- bump version 0.4.0, this is a feature release.
  * Bugfixes:
  - document %%g/%%G format specifiers
  - bug/42, accept NUL characters in input
  - bug/45, correctly display Gregorian and ISO week dates in one
    line
  - bug/46, adhere to ISO group's official formatting of week
    dates
  - bug/47, allow rounding of Epoch based timestamps
  - bug/48, avoid crash for void input to strptime(3)
  * Features:
  - datetest supports --isvalid to conditionalise on date/time
    parsing
  - all tools support --from-locale to parse localised input
  - tools with output formatting support --locale to format
    output according to locale
  * See info page examples and/or README.
* Fri Jan 22 2016 sweet_f_a@gmx.de
- bump version 0.3.5, this is a bugfix release.
  * Bugfixes:
  - bug/40, distinguish between numerals-only dates and durations
  - tests will succeed independent of current date
  * See info page examples and/or README.
- remove dateutils-0.3.4-fix-test-126.patch (upstream applied)
* Sun Jan 10 2016 antoine.belvire@laposte.net
- Fix build:
  * add dateutils-0.3.4-fix-test-126.patch (from upstream)
    (bnc#966644)
* Wed Sep  2 2015 sweet_f_a@gmx.de
- remove old obsoletes line for devel package
* Mon Aug 31 2015 sweet_f_a@gmx.de
- bump version 0.3.4, this is a bugfix release.
  * Bugfixes:
  - bug/39, MacOSX endianness detection
  - bug/38, ddiff day-only durations on date/times
  - dadd +2m bug is fixed, regression
  * See info page examples and/or README.
- remove patches (upstream applied):
  * 0001-fix-build-for-compilers-without-anonymous-struct-ini.patch
  * 0002-fix-dateadd-unix-timestamp-bug.patch
* Sun Aug  2 2015 mpluskal@suse.com
- Correct previous changelog entries (incorrect patch names)
* Mon Jun 15 2015 sweet_f_a@gmx.de
- add 0002-fix-dateadd-unix-timestamp-bug.patch
* Wed Jun 10 2015 sweet_f_a@gmx.de
- bump version 0.3.3, this is a feature release.
  * Features:
  - to clarify purpose and avoid name clashes prefix binaries
    with "date". This results in: dateadd, dateconv, ... etc.
  - provide compatibilty through configure switch --with-old-names
  - provide single digit years through %%_y
  - allow rounding of ISO-week dates (ywd) to week numbers
  * Bugfixes:
  - dashes behind a date do not count as tz indicator
  - UTC/TAI/GPS special coordinated zones work on systems without
    leap second support
  * See info page examples and/or README
- add 0001-fix-build-for-compilers-without-anonymous-struct-ini.patch
  to support broken compilers (SLE 11, RHEL 6, etc.)
* Thu Mar  5 2015 sweet_f_a@gmx.de
- bump version 0.3.2, this is a bugfix release.
  * Bugfixes:
  - out of range minutes will be discarded
  - bug 30 (malicious input crashes dconv) has been fixed
  * Features:
  - military midnight stamps are supported (T24:00:00)
  - 8601 ordinal dates (year + doy) are recognised directly
    (`-f yd`)
  - strptime(1) can behave in a locale-dependent way
  * See info page examples and/or README.
* Fri Jan 16 2015 sweet_f_a@gmx.de
- sort out distros with and without octave
* Tue Oct  7 2014 sweet_f_a@gmx.de
- bump version 0.3.1, this is a bugfix release.
  * Bugfixes:
  - octave/matlab code is distributed fully
  - negative durations with refined units are minus-signed only
    once
  - ddiff is entirely anticommutative now
  - tests don't fail if zones don't exist on the build system
  - dseq with empty ranges will no longer produce output (just as
    seq(1))
  - arbitrary integers are not interpreted as time anymore
  - when converting from zone info properly clear zone difference
    for %%Z
  - dseq(1) will automatically resort to +1mo and +1y iterators
    for wildcarded ymd dates
  - dadd(1)'ing ywd dates with output as ymd works properly now
  * Features:
  - ddiff can output nanosecond diffs
  - automatic fix-up of dates is documented now
  - parser errors and fix ups are reported through return code 2
  - dseq with no `-f|--format` stays in the calendric system of
    the start value instead of converting all output to ymd
  * See info page examples and/or README.
* Tue Aug 26 2014 sweet_f_a@gmx.de
- bump version 0.3.0, this is a feature release.
  * Features:
  - dgrep supports time zones both for the expression and the
    input
  - timezones can be specified by alternative codes and
    [tzmap files][1]
  - new tool dzone to inspect date/times in multiple timezones in
    bulk
  - new tool dsort to sort input chronologically
  - gengetopt and help2man maintainer dependencies removed
  - lilian/julian inputs via `-i ldn` and `-i jdn`
  - ymcw dates now follow ISO 8601 in using 07 to denote Sunday
  * Bugfixes:
  - ddiff takes differences between a unix epoch stamp and a
    date/time
  - zone converter assigns correct sign to zone difference when
    using %%Z
  - weekdays are properly calculated from epoch stamps (issue 24)
  * See info page examples and/or README.
    [1]: http://www.fresse.org/dateutils/tzmaps.html
- enable Octave/Matlab plugin
- remove useless devel package
* Wed Jan 29 2014 sweet_f_a@gmx.de
- bump version 0.2.7, this is a feature release.
  * Features:
  - dgrep supports -v|--invert-match like grep
  - output specifier %%G is supported for compatibility with POSIX
  - ddiff calculates year-day differences
  - ddiff calculates ISO-week date differences
  - ddiff output can be zero and space padded through 0 and SPC
    modifier
  - zoneinfo database on AIX >= 6.1 is taken into account
  * Bug fixes:
  - ddiff can calculate full year differences, [issue 21][1] fixed
  - dseq now accepts %%W, %%V output formats, [issue 22][2] fixed
  - builds with clang >= 3.3 work again, [clang bug 18028][3]
  * See info page examples and/or README.
    [1]: https://github.com/hroptatyr/dateutils/issues/21
    [2]: https://github.com/hroptatyr/dateutils/issues/22
    [3]: http://llvm.org/bugs/show_bug.cgi?id=18028
* Tue Oct 29 2013 sweet_f_a@gmx.de
- bump version 0.2.6, this is a bug fix release.
  * issue 19, -q|--quiet no longer sends some commands into an
    inf-loop
  * netbsd test failures are fixed (due to missing leap seconds)
  * AIX builds are supported (getopt_long() is part of the code
    now)
  * internally the test harness is migrated to the cli-testing tool
    this fixes an issue when tests are run in directories with odd
    names (spaces, dollar signs, etc. in the path name)
  * See info page examples and/or README.
* Thu Jul 25 2013 sweet_f_a@gmx.de
- bump version 0.2.5, this is a bug fix release.
  * issue 18, long inputs to a short specifier string will yield an
    error
  * consume zone specs (a la +1200) in the input via %%Z specifier
  * ddiff's stdin stamps will undergo conversion according to
  - -from-zone
  * clean up dist for inclusion in debian
  * See info page examples and/or README.-
* Thu Feb  7 2013 sweet_f_a@gmx.de
- bump version 0.2.4, this is a bug fix release.
  * added special output format `jdn' and `ldn' for julian/lilian
    day number
  * multiple occurrences of date/times within one line are now all
    processed rather than only the first occurrence
  * zone difference specifier (%%Z) is supported for parsing and
    printing
  * matlab zone converter tzconv has been added
  * building with icc 13 works now
  * many gcc warnings are fixed
  * See info page examples and/or README.
* Fri Sep 14 2012 sweet_f_a@gmx.de
- bump version 0.2.3, this is a bug fix and feature release.
  * ISO 8601 week dates are now first class objectsi
    (of type DT_YWD)
  * introduce %%rY specifier to denote years in calendars that
    deviate from the Gregorian year
  * dgrep accepts short-hand inputs (today, now, etc.) and also
    inputs as specified by -i
  * dadd'ing months and years to YMCW dates works now
  * zoneinfo files with only transitions in the past are handled
    properly (bug #10)
  * dseq with just 1 argument is working properly (story #36051287)
  * See info page examples and/or README.
* Fri Jul 20 2012 sweet_f_a@gmx.de
- bump version 0.2.2, this is a bug fix and feature release.
  * Olson's zoneinfo database files are checked for at configure
    time
  * leap-aware calculations use shipped leapseconds file
  * ddiff and dadd can take leap-second transitions into account
  * issue 7: ddiff without arguments does not segfault
  * issue 8: dadd copes with huge summands
  * issue 9: dadd stumbles on ymcw dates
  * bug 33104651: bday negative difference A > B ddiff A B -f %%db
    is wrong
  * See info page examples and/or README.
* Tue Jun 19 2012 sweet_f_a@gmx.de
- bump version 0.2.1, this is a bug fix and feature release.
  * The dadd tool now supports mass-adding durations (from stdin).
  * The ddiff tool is now time zone aware.
  * A new tool dround is added to round dates or times or
    date-times to the next occurrence of what's given as
    round-spec.
  * Bug fixes:
  - issue 7: ddiff without arguments does not segfault
  - issue 8: dadd copes with huge summands
  * See info page examples and/or README.
* Tue Apr 10 2012 sweet_f_a@gmx.de
- bump version 0.2.0, this is a feature release.
  * The distinction between binaries for date, time and date-time
    processing is cleared up by a unified set of tools, prefixed
    with `d'.
    Thus:
    dadd + tadd -> dadd
    dconv + tconv + dtconv -> dconv
    ddiff + tdiff -> ddiff
    dgrep + tgrep -> dgrep
    dseq + tseq -> dseq
    dtest + ttest -> dtest
  * Furthermore, all tools now fully cope with dates, times and
    date-times.
  * Virtual timezones have been added (use `GPS' or `TAI').
  * See info page examples and/or README.
* Fri Mar 23 2012 sweet_f_a@gmx.de
- bump version 0.1.10, this is a bug fix release.
  * account for big-endian machines
  * GNUisms (mempcpy() and getline()) are removed
  * inf-loop in tseq is fixed (bug #6)
  * nanoseconds are preserved upon time zone conversion
- add byteswap.patch to fix build for old distros
* Wed Feb  1 2012 sweet_f_a@gmx.de
- bump version 0.1.9, this is a bug fix release.
  * The code for date addition is refactored, with it a new
    duration type is introduced, DT_MD, to capture larger month and
    day summands.
* Tue Jan  3 2012 sweet_f_a@gmx.de
- bump version 0.1.8, this is a bug fix release.
  * A bit fiddling bug gave erroneous results in `dconv now'.
  * Furtherly, date expressions (for dgrep et al.) can now be
    arbitrarily joined with conjunctions (&&) and disjunctions (||)
    as well as negations (!).
* Thu Oct 27 2011 sweet_f_a@gmx.de
- bump version 0.1.7, this is a bug fix release.
* Fri Oct 21 2011 sweet_f_a@gmx.de
- bump version 0.1.6
* Wed Sep 14 2011 sweet_f_a@gmx.de
- initial package datetools 0.1.2
